@@ -3,6 +3,7 @@ from django import template
 
 register = template.Library()
 
+
 @register.simple_tag
-def app_name():
+def invoice_app_name():
     return app_sett.INVOICES_APP_NAME
